This patch enables the use of "-display" parameter to specify the 
framebuffer device to use (other than the default /dev/fb0) when
using fb driver.

James

diff -ur links-2.7-old/default.c links-2.7/default.c
--- links-2.7-old/default.c	2012-06-26 06:57:10.000000000 +0700
+++ links-2.7/default.c	2014-02-21 13:29:15.940001935 +0700
@@ -1392,7 +1392,7 @@
 "  For Xwindow it is size of a window in format WIDTHxHEIGHT.\n"
 "\n"
 " -display <x-display>\n"
-"  Set Xwindow display.\n"
+"  Set Xwindow display. For fb driver, specify /dev/fb to use.\n"
 "\n"
 " -force-html\n"
 "  Treat files with unknown type as html rather than text.\n"
diff -ur links-2.7-old/framebuffer.c links-2.7/framebuffer.c
--- links-2.7-old/framebuffer.c	2012-06-26 02:29:21.000000000 +0700
+++ links-2.7/framebuffer.c	2014-02-21 13:57:08.935002733 +0700
@@ -80,6 +80,7 @@
 static void fb_draw_bitmap(struct graphics_device *dev,struct bitmap* hndl, int x, int y);
 
 static unsigned char *fb_driver_param;
+static unsigned char *fb_fbdev; // the framebuffer device to use, /dev/fbX
 struct graphics_driver fb_driver;
 static int have_cmap=0;
 static volatile int fb_active=1;
@@ -1043,7 +1044,7 @@
 	/* don't check error */
 }
 
-static unsigned char *fb_init_driver(unsigned char *param, unsigned char *ignore)
+static unsigned char *fb_init_driver(unsigned char *param, unsigned char *fbdev)
 {
 	unsigned char *e;
 	struct stat st;
@@ -1120,12 +1121,16 @@
 		return e;
 	}
 
-	EINTRLOOP(fb_handler, open("/dev/fb0", O_RDWR));
+	/* choose which fbdev to use */
+	fb_fbdev="/dev/fb0";
+	if(fbdev != NULL && fbdev[0])
+		fb_fbdev=stracpy(fbdev);
+	EINTRLOOP(fb_handler, open(fb_fbdev, O_RDWR));
 	if (fb_handler==-1) {
 		fb_switch_shutdown();
 		if(fb_driver_param) { mem_free(fb_driver_param); fb_driver_param=NULL; }
 		fb_show_cursor();
-		return stracpy(cast_uchar "Cannot open /dev/fb0.\n");
+		return stracpy(cast_uchar "Cannot open framebuffer device.\n");
 	}
 
 	EINTRLOOP(rs, ioctl (fb_handler, FBIOGET_VSCREENINFO, &vi));
diff -ur links-2.7-old/links.1 links-2.7/links.1
--- links-2.7-old/links.1	2012-06-26 07:30:22.000000000 +0700
+++ links-2.7/links.1	2014-02-21 13:29:35.600001945 +0700
@@ -64,7 +64,7 @@
 
 .TP
 \f3-display \f2<x-display>\f1
-Set Xwindow display.
+Set Xwindow display. For fb driver, specify which /dev/fb to use.
 
 .TP
 \f3-force-html\f1
